﻿*************************************************************************************************************
*** SINTAXIS DE TABULADOS MÓDULO AMBIENTAL - ENEMDU 2017.
*************************************************************************************************************
A.  Apertura de la base de variables ambientales ENEMDU Diciembre 2017 e inicialización de variables de desglose.

GET
  FILE='C:\ENEMDU\Datos\Bases\201712_EnemduBDD_ambiente.sav'.
DATASET NAME Ambientales WINDOW=FRONT.

SORT CASES BY AREA (A) CIUDAD (A) CONGLOMERADO (A) ZONA (A) SECTOR (A) PANELM (A) VIVIENDA (A) HOGAR (A).

COMPUTE NACIONAL=1.
VARIABLE LABELS NACIONAL "NACIONAL".
VALUE LABELS NACIONAL 1"Nacional".

IF (CIUDAD=170150) DOMIN=1.
IF (CIUDAD=90150) DOMIN=2.
IF (CIUDAD=10150) DOMIN=3.
IF (CIUDAD=180150) DOMIN=4.
IF (CIUDAD=70150) DOMIN=5.

VARIABLE LABELS DOMIN 'Ciudades de Dominio'.
VALUE LABELS DOMIN 1 'Quito' 2 'Guayaquil' 3 'Cuenca' 4 'Ambato' 5 'Machala'.
EXECUTE.

COMPUTE prov = TRUNC(CIUDAD/1e4).
FREQUENCIES prov.

VALUE LABELS prov 1'Azuay'
2'Bolívar'
3'Cañar'
4'Carchi'
5'Cotopaxi'
6'Chimborazo'
7'El Oro'
8'Esmeraldas'
9'Guayas'
10'Imbabura'
11'Loja'
12'Los Ríos'
13'Manabí'
14'Morona-Santiago'
15'Napo'
16'Pastaza'
17'Pichincha'
18'Tungurahua'
19'Zamora-Chinchipe'
20'Galápagos'
21'Sucumbíos'
22'Orellana'
23'Sto. Dgo de los Tsáchilas'
24'Santa Elena'
90'Zona No Delimitada'.

RECODE prov (1 thru 6, 10, 11, 17, 18 = 1) (7, 8, 9, 12, 13, 23, 24, 90 = 2) (14, 15, 16, 19, 21, 22 = 3) (20 = 4) INTO REG_NATURAL.
VARIABLE LABELS REG_NATURAL "Región Natural - DEAGA".
VALUE LABELS REG_NATURAL 1'Sierra' 2'Costa' 3'Amazonía' 4'Región Insular'.
FREQUENCIES REG_NATURAL.

*********************************************************************************************************************************************************************************
B. Fusión de variables de la base VIVIENDA_HOGAR con la base AMBIENTE.
*********************************************************************************************************************************************************************************

GET
  FILE='C:\ENEMDU\Datos\Bases\201712_EnemduBDD_viviendahogar.sav'.
DATASET NAME Vivienda WINDOW=FRONT.

ALTER TYPE area (F1) ciudad (F6) conglomerado (A6) zona (A3) sector (A3) panelm (A3) vivienda (F2) hogar (F1).
COMPUTE conglomerado = REPLACE(conglomerado, " ", "0").
COMPUTE zona = REPLACE(zona, " ", "0").
COMPUTE sector = REPLACE(sector, " ", "0").
COMPUTE panelm = REPLACE(panelm, " ", "0").
EXECUTE.

SORT CASES BY area (A) ciudad (A) conglomerado (A) zona (A) sector (A) panelm (A) vivienda (A) hogar (A).

DATASET ACTIVATE Ambientales.
SORT CASES BY AREA (A) CIUDAD (A) CONGLOMERADO (A) ZONA (A) SECTOR (A) PANELM (A) VIVIENDA (A) HOGAR (A).

MATCH FILES /TABLE=*
  /FILE='Vivienda'
  /RENAME (eq0102 eq0202 eq0302 eq0402 eq0502 eq0602 eq0702 eq0802 eq0902 eq1002 eq1102 eq1202 
    eq1302 eq1402 eq1502 eq1602 eq1702 eq1802 eq1902 fexp plan_muestreo vi01 vi02 vi03a vi03b vi04a 
    vi04b vi05a vi05b vi06 vi07 vi07a1 vi07a2 vi08 vi08a vi08b vi10 vi11 vi12 vi13a vi13b vi13c vi13d 
    vi14 vi15 vi16a vi16b vi16d vi17 vi18 vi19a vi19b vi20a vi20b vi22 vi23 vi24 vi25 = d0 d1 d2 d3 d4 
    d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 
    d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 d50 d51 d52 d53 d54 d55 
    d56 d57) 
  /BY area ciudad conglomerado zona sector panelm vivienda hogar
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 
    d50 d51 d52 d53 d54 d55 d56 d57.
EXECUTE.

DATASET ACTIVATE Ambientales.
DATASET CLOSE Vivienda.

*********************************************************************************************************************************************************************************
C. Imputacón virtual de variables de la base AMBIENTE previo al cálculo de sus respectivos indicadores.
*********************************************************************************************************************************************************************************
* C.1. Imputación de la variable A0601: Reusan el agua (para regar, fregar, tirar al baño)?.

* Existen 11 casos muestrales registrados incorrectamente como 3 = No Aplica. Por tanto, se necesita aplicar el proceso de imputación por
* simulación basada en variables binomiales. La probabilidad a priori de asignación desde la categoría 3 = No aplica hacia la categoría 1 = Sí
* es igual a 11402 / (11402 + 18610) = 11402 / 30012 = 5701 / 15006 = 0.3799147.

WEIGHT OFF.
FILTER OFF.
USE ALL.

FREQUENCIES A0601.

COMPUTE A0601_1 = (A0601 = 3).
FREQUENCIES A0601_1.

SET RNG=MT MTINDEX=3. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.3799147, y que minimice su desviación típica.

DO IF (A0601_1 = 1).
COMPUTE X10 = RV.BINOM(1, 5701 / 15006).
COMPUTE X11 = RV.BINOM(1, 5701 / 15006).
COMPUTE X12 = RV.BINOM(1, 5701 / 15006).
COMPUTE X13 = RV.BINOM(1, 5701 / 15006).
COMPUTE X14 = RV.BINOM(1, 5701 / 15006).
COMPUTE X15 = RV.BINOM(1, 5701 / 15006).
COMPUTE X16 = RV.BINOM(1, 5701 / 15006).
COMPUTE X17 = RV.BINOM(1, 5701 / 15006).
COMPUTE X18 = RV.BINOM(1, 5701 / 15006).
COMPUTE X19 = RV.BINOM(1, 5701 / 15006).
END IF.

COMPUTE XS1 = SUM.1(X10, X11, X12, X13, X14, X15, X16, X17, X18, X19).

DESCRIPTIVES VARIABLES=X10 X11 X12 X13 X14 X15 X16 X17 X18 X19 XS1
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X10 X11 X12 X13 X14 X15 X16 X17 X18 X19.

RECODE A0601 (ELSE = COPY) INTO A0601_MISS. /* Esta variable simulada sustituirá a la original para cálculos de tabulados e indicadores.
FREQUENCIES A0601_MISS.

DO IF (A0601_1 = 1).
IF (XS1 <= 3.8182) A0601_MISS = 1. /* XS1 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS1 > 3.8182)  A0601_MISS = 2. /* XS1 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

VARIABLE LABELS A0601_MISS "A0601 SIN INCONSISTENCIAS".
VALUE LABELS A0601_MISS 1'Sí' 2'No'.
FREQUENCIES A0601_MISS.

DELETE VARIABLES A0601_1.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.2. Imputación de la variable A0602: Utilizan balde en lugar de manguera para ciertas actividades? con respecto a la variable VI16C.

* Existen 48 casos muestrales registrados incorrectamente como 1 = Sí o 2 = No. Estos valores serán pasados en forma sencilla a la
* categoría 3 = No aplica por simple reasignación.

WEIGHT OFF.
FILTER OFF.
USE ALL.

CTABLES
  /VLABELS VARIABLES=vi16c A0602 DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0602
  /CATEGORIES VARIABLES=vi16c A0602 ORDER=A KEY=VALUE EMPTY=INCLUDE.

RECODE A0602 (ELSE = COPY) INTO A0602_T.
FREQUENCIES A0602_T.

IF (ANY(VI16C, 3, 4) & ANY(A0602, 1, 2)) A0602_T = 3.
CTABLES
  /VLABELS VARIABLES=vi16c A0602_T DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0602_T
  /CATEGORIES VARIABLES=vi16c A0602_T ORDER=A KEY=VALUE EMPTY=INCLUDE.

* Una vez hecha la reasignación de los 1 = Sí y 2 = No, se procede a simular los valores erróneos 3 = No Aplica. Por tanto, se necesita
*  aplicar el proceso de imputación por simulación basada en variables binomiales. La probabilidad a priori de asignación desde la categoría
* 3 = No aplica hacia la categoría 1 = Sí es igual a 11617 / (11617 + 10293) = 11617 / 21910 = 0.5302145, siempre que VI16C = 1.
* Para el caso en que VI16C = 2, la probabilidad a priori de asignación desde la categoría 3 = No aplica hacia la categoría 1 = Sí es igual
* a 3203 / (3203 + 2493) = 3203 / 5696 = 0.5623244.

COMPUTE A0602_VI16C_1 = (VI16C = 1 & A0602_T = 3).
COMPUTE A0602_VI16C_2 = (VI16C = 2 & A0602_T = 3).
FREQUENCIES A0602_VI16C_1 A0602_VI16C_2.

SET RNG=MT MTINDEX=5. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.5302145, y que minimice su desviación típica.

DO IF (A0602_VI16C_1 = 1).
COMPUTE X10 = RV.BINOM(1, 11617 / 21910).
COMPUTE X11 = RV.BINOM(1, 11617 / 21910).
COMPUTE X12 = RV.BINOM(1, 11617 / 21910).
COMPUTE X13 = RV.BINOM(1, 11617 / 21910).
COMPUTE X14 = RV.BINOM(1, 11617 / 21910).
COMPUTE X15 = RV.BINOM(1, 11617 / 21910).
COMPUTE X16 = RV.BINOM(1, 11617 / 21910).
COMPUTE X17 = RV.BINOM(1, 11617 / 21910).
COMPUTE X18 = RV.BINOM(1, 11617 / 21910).
COMPUTE X19 = RV.BINOM(1, 11617 / 21910).
END IF.

COMPUTE XS1 = SUM.1(X10, X11, X12, X13, X14, X15, X16, X17, X18, X19).

DESCRIPTIVES VARIABLES=X10 X11 X12 X13 X14 X15 X16 X17 X18 X19 XS1
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X10 X11 X12 X13 X14 X15 X16 X17 X18 X19.

SET RNG=MT MTINDEX=9. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.5623244, y que minimice su desviación típica.

DO IF (A0602_VI16C_2 = 1).
COMPUTE X20 = RV.BINOM(1, 3203 / 5696).
COMPUTE X21 = RV.BINOM(1, 3203 / 5696).
COMPUTE X22 = RV.BINOM(1, 3203 / 5696).
COMPUTE X23 = RV.BINOM(1, 3203 / 5696).
COMPUTE X24 = RV.BINOM(1, 3203 / 5696).
COMPUTE X25 = RV.BINOM(1, 3203 / 5696).
COMPUTE X26 = RV.BINOM(1, 3203 / 5696).
COMPUTE X27 = RV.BINOM(1, 3203 / 5696).
COMPUTE X28 = RV.BINOM(1, 3203 / 5696).
COMPUTE X29 = RV.BINOM(1, 3203 / 5696).
END IF.

COMPUTE XS2 = SUM.1(X20, X21, X22, X23, X24, X25, X26, X27, X28, X29).

DESCRIPTIVES VARIABLES=X20 X21 X22 X23 X24 X25 X26 X27 X28 X29 XS2
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X20 X21 X22 X23 X24 X25 X26 X27 X28 X29.

RECODE A0602_T (ELSE = COPY) INTO A0602_MISS. /* Esta variable simulada sustituirá a la original para cálculos de tabulados e indicadores.
FREQUENCIES A0602_MISS.

DO IF (A0602_VI16C_1 = 1).
IF (XS1 <= 5.2960) A0602_MISS = 1. /* XS1 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS1 > 5.2960)  A0602_MISS = 2. /* XS1 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0602_MISS.

DO IF (A0602_VI16C_2 = 1).
IF (XS2 <= 5.6115) A0602_MISS = 1. /* XS2 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS2 > 5.6115)  A0602_MISS = 2. /* XS2 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0602_MISS.

VARIABLE LABELS A0602_MISS "A0602 SIN INCONSISTENCIAS".
VALUE LABELS A0602_MISS 1'Sí' 2'No' 3'No aplica'.

CTABLES
  /VLABELS VARIABLES=vi16c A0602_MISS DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0602_MISS
  /CATEGORIES VARIABLES=vi16c A0602_MISS ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A0602_T A0602_VI16C_1 A0602_VI16C_2.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.3. Imputación de la variable A0603: Cierran las llaves mientras jabonan los platos, se bañan, se cepillan los dientes? con respecto a la variable VI16C.

* Existen 8 casos muestrales registrados incorrectamente como 1 = Sí o 2 = No. Estos valores serán pasados en forma sencilla a la
* categoría 3 = No aplica por simple reasignación.

WEIGHT OFF.
FILTER OFF.
USE ALL.

CTABLES
  /VLABELS VARIABLES=vi16c A0603 DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0603
  /CATEGORIES VARIABLES=vi16c A0603 ORDER=A KEY=VALUE EMPTY=INCLUDE.

RECODE A0603 (ELSE = COPY) INTO A0603_T.
FREQUENCIES A0603_T.

IF (ANY(VI16C, 3, 4) & ANY(A0603, 1, 2)) A0603_T = 3.
CTABLES
  /VLABELS VARIABLES=vi16c A0603_T DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0603_T
  /CATEGORIES VARIABLES=vi16c A0603_T ORDER=A KEY=VALUE EMPTY=INCLUDE.

* Una vez hecha la reasignación de los 1 = Sí y 2 = No, se procede a simular los valores erróneos 3 = No Aplica. Por tanto, se necesita
*  aplicar el proceso de imputación por simulación basada en variables binomiales. La probabilidad a priori de asignación desde la categoría
* 3 = No aplica hacia la categoría 1 = Sí es igual a 20410 / (20410 + 1683) = 20410 / 22093 = 0.923822, siempre que VI16C = 1.
* Para el caso en que VI16C = 2, la probabilidad a priori de asignación desde la categoría 3 = No aplica hacia la categoría 1 = Sí es igual
* a 4038 / (4038 + 1625) = 4038 / 5663 = 0.7130496.

COMPUTE A0603_VI16C_1 = (VI16C = 1 & A0603_T = 3).
COMPUTE A0603_VI16C_2 = (VI16C = 2 & A0603_T = 3).
FREQUENCIES A0603_VI16C_1 A0603_VI16C_2.

SET RNG=MT MTINDEX=1. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.923822, y que minimice su desviación típica.

DO IF (A0603_VI16C_1 = 1).
COMPUTE X10 = RV.BINOM(1, 20410 / 22093).
COMPUTE X11 = RV.BINOM(1, 20410 / 22093).
COMPUTE X12 = RV.BINOM(1, 20410 / 22093).
COMPUTE X13 = RV.BINOM(1, 20410 / 22093).
COMPUTE X14 = RV.BINOM(1, 20410 / 22093).
COMPUTE X15 = RV.BINOM(1, 20410 / 22093).
COMPUTE X16 = RV.BINOM(1, 20410 / 22093).
COMPUTE X17 = RV.BINOM(1, 20410 / 22093).
COMPUTE X18 = RV.BINOM(1, 20410 / 22093).
COMPUTE X19 = RV.BINOM(1, 20410 / 22093).
END IF.

COMPUTE XS1 = SUM.1(X10, X11, X12, X13, X14, X15, X16, X17, X18, X19).

DESCRIPTIVES VARIABLES=X10 X11 X12 X13 X14 X15 X16 X17 X18 X19 XS1
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X10 X11 X12 X13 X14 X15 X16 X17 X18 X19.

SET RNG=MT MTINDEX=7. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.7130496, y que minimice su desviación típica.

DO IF (A0603_VI16C_2 = 1).
COMPUTE X20 = RV.BINOM(1, 4038 / 5663).
COMPUTE X21 = RV.BINOM(1, 4038 / 5663).
COMPUTE X22 = RV.BINOM(1, 4038 / 5663).
COMPUTE X23 = RV.BINOM(1, 4038 / 5663).
COMPUTE X24 = RV.BINOM(1, 4038 / 5663).
COMPUTE X25 = RV.BINOM(1, 4038 / 5663).
COMPUTE X26 = RV.BINOM(1, 4038 / 5663).
COMPUTE X27 = RV.BINOM(1, 4038 / 5663).
COMPUTE X28 = RV.BINOM(1, 4038 / 5663).
COMPUTE X29 = RV.BINOM(1, 4038 / 5663).
END IF.

COMPUTE XS2 = SUM.1(X20, X21, X22, X23, X24, X25, X26, X27, X28, X29).

DESCRIPTIVES VARIABLES=X20 X21 X22 X23 X24 X25 X26 X27 X28 X29 XS2
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X20 X21 X22 X23 X24 X25 X26 X27 X28 X29.

RECODE A0603_T (ELSE = COPY) INTO A0603_MISS. /* Esta variable simulada sustituirá a la original para cálculos de tabulados e indicadores.
FREQUENCIES A0603_MISS.

DO IF (A0603_VI16C_1 = 1).
IF (XS1 <= 9.2250) A0603_MISS = 1. /* XS1 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS1 > 9.2250)  A0603_MISS = 2. /* XS1 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0603_MISS.

DO IF (A0603_VI16C_2 = 1).
IF (XS2 <= 7.1802) A0603_MISS = 1. /* XS2 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS2 > 7.1802)  A0603_MISS = 2. /* XS2 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0603_MISS.

VARIABLE LABELS A0603_MISS "A0603 SIN INCONSISTENCIAS".
VALUE LABELS A0603_MISS 1'Sí' 2'No' 3'No aplica'.

CTABLES
  /VLABELS VARIABLES=vi16c A0603_MISS DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0603_MISS
  /CATEGORIES VARIABLES=vi16c A0603_MISS ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A0603_T A0603_VI16C_1 A0603_VI16C_2.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.4. Imputación de la variable A0604: Se duchan en menos de 10 minutos? con respecto a la variable VI16C.

* Existen 8 casos muestrales registrados incorrectamente como 1 = Sí o 2 = No. Estos valores serán pasados en forma sencilla a la
* categoría 3 = No aplica por simple reasignación.

WEIGHT OFF.
FILTER OFF.
USE ALL.

CTABLES
  /VLABELS VARIABLES=vi16c A0604 DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0604
  /CATEGORIES VARIABLES=vi16c A0604 ORDER=A KEY=VALUE EMPTY=INCLUDE.

RECODE A0604 (ELSE = COPY) INTO A0604_T.
FREQUENCIES A0604_T.

IF (ANY(VI16C, 3, 4) & ANY(A0604, 1, 2)) A0604_T = 3.
CTABLES
  /VLABELS VARIABLES=vi16c A0604_T DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0604_T
  /CATEGORIES VARIABLES=vi16c A0604_T ORDER=A KEY=VALUE EMPTY=INCLUDE.

* Una vez hecha la reasignación de los 1 = Sí y 2 = No, se procede a simular los valores erróneos 3 = No Aplica. Por tanto, se necesita
*  aplicar el proceso de imputación por simulación basada en variables binomiales. La probabilidad a priori de asignación desde la categoría
* 3 = No aplica hacia la categoría 1 = Sí es igual a 16772 / (16772 + 5202) = 16772 / 21974 = 0.7632657, siempre que VI16C = 1.
* Para el caso en que VI16C = 2, la probabilidad a priori de asignación desde la categoría 3 = No aplica hacia la categoría 1 = Sí es igual
* a 3188 / (3188 + 2170) = 3188 / 5358 = 0.59499813.

COMPUTE A0604_VI16C_1 = (VI16C = 1 & A0604_T = 3).
COMPUTE A0604_VI16C_2 = (VI16C = 2 & A0604_T = 3).
FREQUENCIES A0604_VI16C_1 A0604_VI16C_2.

SET RNG=MT MTINDEX=4. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.7632657, y que minimice su desviación típica.

DO IF (A0604_VI16C_1 = 1).
COMPUTE X10 = RV.BINOM(1, 16772 / 21974).
COMPUTE X11 = RV.BINOM(1, 16772 / 21974).
COMPUTE X12 = RV.BINOM(1, 16772 / 21974).
COMPUTE X13 = RV.BINOM(1, 16772 / 21974).
COMPUTE X14 = RV.BINOM(1, 16772 / 21974).
COMPUTE X15 = RV.BINOM(1, 16772 / 21974).
COMPUTE X16 = RV.BINOM(1, 16772 / 21974).
COMPUTE X17 = RV.BINOM(1, 16772 / 21974).
COMPUTE X18 = RV.BINOM(1, 16772 / 21974).
COMPUTE X19 = RV.BINOM(1, 16772 / 21974).
END IF.

COMPUTE XS1 = SUM.1(X10, X11, X12, X13, X14, X15, X16, X17, X18, X19).

DESCRIPTIVES VARIABLES=X10 X11 X12 X13 X14 X15 X16 X17 X18 X19 XS1
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X10 X11 X12 X13 X14 X15 X16 X17 X18 X19.

SET RNG=MT MTINDEX=1. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.59499813, y que minimice su desviación típica.

DO IF (A0604_VI16C_2 = 1).
COMPUTE X20 = RV.BINOM(1, 3188 / 5358).
COMPUTE X21 = RV.BINOM(1, 3188 / 5358).
COMPUTE X22 = RV.BINOM(1, 3188 / 5358).
COMPUTE X23 = RV.BINOM(1, 3188 / 5358).
COMPUTE X24 = RV.BINOM(1, 3188 / 5358).
COMPUTE X25 = RV.BINOM(1, 3188 / 5358).
COMPUTE X26 = RV.BINOM(1, 3188 / 5358).
COMPUTE X27 = RV.BINOM(1, 3188 / 5358).
COMPUTE X28 = RV.BINOM(1, 3188 / 5358).
COMPUTE X29 = RV.BINOM(1, 3188 / 5358).
END IF.

COMPUTE XS2 = SUM.1(X20, X21, X22, X23, X24, X25, X26, X27, X28, X29).

DESCRIPTIVES VARIABLES=X20 X21 X22 X23 X24 X25 X26 X27 X28 X29 XS2
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X20 X21 X22 X23 X24 X25 X26 X27 X28 X29.

RECODE A0604_T (ELSE = COPY) INTO A0604_MISS. /* Esta variable simulada sustituirá a la original para cálculos de tabulados e indicadores.
FREQUENCIES A0604_MISS.

DO IF (A0604_VI16C_1 = 1).
IF (XS1 <= 7.6289) A0604_MISS = 1. /* XS1 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS1 > 7.6289)  A0604_MISS = 2. /* XS1 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0604_MISS.

DO IF (A0604_VI16C_2 = 1).
IF (XS2 <= 5.9497) A0604_MISS = 1. /* XS2 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS2 > 5.9497)  A0604_MISS = 2. /* XS2 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0604_MISS.

VARIABLE LABELS A0604_MISS "A0604 SIN INCONSISTENCIAS".
VALUE LABELS A0604_MISS 1'Sí' 2'No' 3'No aplica'.

CTABLES
  /VLABELS VARIABLES=vi16c A0604_MISS DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0604_MISS
  /CATEGORIES VARIABLES=vi16c A0604_MISS ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A0604_T A0604_VI16C_1 A0604_VI16C_2.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.5. Imputación de la variable A0605: Revisan regularmente las tuberías? con respecto a la variable VI16C.

* Existen 8 casos muestrales registrados incorrectamente como 1 = Sí o 2 = No. Estos valores serán pasados en forma sencilla a la
* categoría 3 = No aplica por simple reasignación.

WEIGHT OFF.
FILTER OFF.
USE ALL.

CTABLES
  /VLABELS VARIABLES=vi16c A0605 DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0605
  /CATEGORIES VARIABLES=vi16c A0605 ORDER=A KEY=VALUE EMPTY=INCLUDE.

RECODE A0605 (ELSE = COPY) INTO A0605_T.
FREQUENCIES A0605_T.

IF (ANY(VI16C, 3, 4) & ANY(A0605, 1, 2)) A0605_T = 3.
CTABLES
  /VLABELS VARIABLES=vi16c A0605_T DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0605_T
  /CATEGORIES VARIABLES=vi16c A0605_T ORDER=A KEY=VALUE EMPTY=INCLUDE.

* Una vez hecha la reasignación de los 1 = Sí y 2 = No, se procede a simular los valores erróneos 3 = No Aplica. Por tanto, se necesita
*  aplicar el proceso de imputación por simulación basada en variables binomiales. La probabilidad a priori de asignación desde la categoría
* 3 = No aplica hacia la categoría 1 = Sí es igual a 12528 / (12528 + 9567) = 12528 / 22095 = 0.56700611, siempre que VI16C = 1.
* Para el caso en que VI16C = 2, la probabilidad a priori de asignación desde la categoría 3 = No aplica hacia la categoría 1 = Sí es igual
* a 2226 / (2226 + 3437) = 2226 / 5663 = 0.39307787.

COMPUTE A0605_VI16C_1 = (VI16C = 1 & A0605_T = 3).
COMPUTE A0605_VI16C_2 = (VI16C = 2 & A0605_T = 3).
FREQUENCIES A0605_VI16C_1 A0605_VI16C_2.

SET RNG=MT MTINDEX=9. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.56700611, y que minimice su desviación típica.

DO IF (A0605_VI16C_1 = 1).
COMPUTE X10 = RV.BINOM(1, 12528 / 22095).
COMPUTE X11 = RV.BINOM(1, 12528 / 22095).
COMPUTE X12 = RV.BINOM(1, 12528 / 22095).
COMPUTE X13 = RV.BINOM(1, 12528 / 22095).
COMPUTE X14 = RV.BINOM(1, 12528 / 22095).
COMPUTE X15 = RV.BINOM(1, 12528 / 22095).
COMPUTE X16 = RV.BINOM(1, 12528 / 22095).
COMPUTE X17 = RV.BINOM(1, 12528 / 22095).
COMPUTE X18 = RV.BINOM(1, 12528 / 22095).
COMPUTE X19 = RV.BINOM(1, 12528 / 22095).
END IF.

COMPUTE XS1 = SUM.1(X10, X11, X12, X13, X14, X15, X16, X17, X18, X19).

DESCRIPTIVES VARIABLES=X10 X11 X12 X13 X14 X15 X16 X17 X18 X19 XS1
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X10 X11 X12 X13 X14 X15 X16 X17 X18 X19.

SET RNG=MT MTINDEX=0. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.39307787, y que minimice su desviación típica.

DO IF (A0605_VI16C_2 = 1).
COMPUTE X20 = RV.BINOM(1, 2226 / 5663).
COMPUTE X21 = RV.BINOM(1, 2226 / 5663).
COMPUTE X22 = RV.BINOM(1, 2226 / 5663).
COMPUTE X23 = RV.BINOM(1, 2226 / 5663).
COMPUTE X24 = RV.BINOM(1, 2226 / 5663).
COMPUTE X25 = RV.BINOM(1, 2226 / 5663).
COMPUTE X26 = RV.BINOM(1, 2226 / 5663).
COMPUTE X27 = RV.BINOM(1, 2226 / 5663).
COMPUTE X28 = RV.BINOM(1, 2226 / 5663).
COMPUTE X29 = RV.BINOM(1, 2226 / 5663).
END IF.

COMPUTE XS2 = SUM.1(X20, X21, X22, X23, X24, X25, X26, X27, X28, X29).

DESCRIPTIVES VARIABLES=X20 X21 X22 X23 X24 X25 X26 X27 X28 X29 XS2
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X20 X21 X22 X23 X24 X25 X26 X27 X28 X29.

RECODE A0605_T (ELSE = COPY) INTO A0605_MISS. /* Esta variable simulada sustituirá a la original para cálculos de tabulados e indicadores.
FREQUENCIES A0605_MISS.

DO IF (A0605_VI16C_1 = 1).
IF (XS1 <= 5.6053) A0605_MISS = 1. /* XS1 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS1 > 5.6053)  A0605_MISS = 2. /* XS1 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0605_MISS.

DO IF (A0605_VI16C_2 = 1).
IF (XS2 <= 3.9360) A0605_MISS = 1. /* XS2 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS2 > 3.9360)  A0605_MISS = 2. /* XS2 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0605_MISS.

VARIABLE LABELS A0605_MISS "A0605 SIN INCONSISTENCIAS".
VALUE LABELS A0605_MISS 1'Sí' 2'No' 3'No aplica'.

CTABLES
  /VLABELS VARIABLES=vi16c A0605_MISS DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0605_MISS
  /CATEGORIES VARIABLES=vi16c A0605_MISS ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A0605_T A0605_VI16C_1 A0605_VI16C_2.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.6. Imputación de la variable A0606: Disponen de economizadores de chorro? con respecto a la variable VI16C.

* Existen 8 casos muestrales registrados incorrectamente como 1 = Sí o 2 = No. Estos valores serán pasados en forma sencilla a la
* categoría 3 = No aplica por simple reasignación.

WEIGHT OFF.
FILTER OFF.
USE ALL.

CTABLES
  /VLABELS VARIABLES=vi16c A0606 DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0606
  /CATEGORIES VARIABLES=vi16c A0606 ORDER=A KEY=VALUE EMPTY=INCLUDE.

RECODE A0606 (ELSE = COPY) INTO A0606_T.
FREQUENCIES A0606_T.

IF (ANY(VI16C, 3, 4) & ANY(A0606, 1, 2)) A0606_T = 3.
CTABLES
  /VLABELS VARIABLES=vi16c A0606_T DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0606_T
  /CATEGORIES VARIABLES=vi16c A0606_T ORDER=A KEY=VALUE EMPTY=INCLUDE.

* Una vez hecha la reasignación de los 1 = Sí y 2 = No, se procede a simular los valores erróneos 3 = No Aplica. Por tanto, se necesita
*  aplicar el proceso de imputación por simulación basada en variables binomiales. La probabilidad a priori de asignación desde la categoría
* 3 = No aplica hacia la categoría 1 = Sí es igual a 2599 / (2599 + 19470) = 2599 / 22069 = 0.117767, siempre que VI16C = 1.
* Para el caso en que VI16C = 2, la probabilidad a priori de asignación desde la categoría 3 = No aplica hacia la categoría 1 = Sí es igual
* a 202 / (2226 + 5427) = 202 / 7653 = 0.026394877.

COMPUTE A0606_VI16C_1 = (VI16C = 1 & A0606_T = 3).
COMPUTE A0606_VI16C_2 = (VI16C = 2 & A0606_T = 3).
FREQUENCIES A0606_VI16C_1 A0606_VI16C_2.

SET RNG=MT MTINDEX=8. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.117767, y que minimice su desviación típica.

DO IF (A0606_VI16C_1 = 1).
COMPUTE X10 = RV.BINOM(1, 2599 / 22069).
COMPUTE X11 = RV.BINOM(1, 2599 / 22069).
COMPUTE X12 = RV.BINOM(1, 2599 / 22069).
COMPUTE X13 = RV.BINOM(1, 2599 / 22069).
COMPUTE X14 = RV.BINOM(1, 2599 / 22069).
COMPUTE X15 = RV.BINOM(1, 2599 / 22069).
COMPUTE X16 = RV.BINOM(1, 2599 / 22069).
COMPUTE X17 = RV.BINOM(1, 2599 / 22069).
COMPUTE X18 = RV.BINOM(1, 2599 / 22069).
COMPUTE X19 = RV.BINOM(1, 2599 / 22069).
END IF.

COMPUTE XS1 = SUM.1(X10, X11, X12, X13, X14, X15, X16, X17, X18, X19).

DESCRIPTIVES VARIABLES=X10 X11 X12 X13 X14 X15 X16 X17 X18 X19 XS1
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X10 X11 X12 X13 X14 X15 X16 X17 X18 X19.

SET RNG=MT MTINDEX=8. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.026394877, y que minimice su desviación típica.

DO IF (A0606_VI16C_2 = 1).
COMPUTE X20 = RV.BINOM(1, 202 / 7653).
COMPUTE X21 = RV.BINOM(1, 202 / 7653).
COMPUTE X22 = RV.BINOM(1, 202 / 7653).
COMPUTE X23 = RV.BINOM(1, 202 / 7653).
COMPUTE X24 = RV.BINOM(1, 202 / 7653).
COMPUTE X25 = RV.BINOM(1, 202 / 7653).
COMPUTE X26 = RV.BINOM(1, 202 / 7653).
COMPUTE X27 = RV.BINOM(1, 202 / 7653).
COMPUTE X28 = RV.BINOM(1, 202 / 7653).
COMPUTE X29 = RV.BINOM(1, 202 / 7653).
END IF.

COMPUTE XS2 = SUM.1(X20, X21, X22, X23, X24, X25, X26, X27, X28, X29).

DESCRIPTIVES VARIABLES=X20 X21 X22 X23 X24 X25 X26 X27 X28 X29 XS2
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X20 X21 X22 X23 X24 X25 X26 X27 X28 X29.

RECODE A0606_T (ELSE = COPY) INTO A0606_MISS. /* Esta variable simulada sustituirá a la original para cálculos de tabulados e indicadores.
FREQUENCIES A0606_MISS.

DO IF (A0606_VI16C_1 = 1).
IF (XS1 <= 1.1719) A0606_MISS = 1. /* XS1 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS1 > 1.1719)  A0606_MISS = 2. /* XS1 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0606_MISS.

DO IF (A0606_VI16C_2 = 1).
IF (XS2 <= 0.2621) A0606_MISS = 1. /* XS2 debe ser menor que la media de ella misma para asignar los valores a la categoría 1 = Sí.
IF (XS2 > 0.2621)  A0606_MISS = 2. /* XS2 debe ser mayor o igual que la media de ella misma para asignar los valores a la categoría 2 = No.
END IF.

FREQUENCIES A0606_MISS.

VARIABLE LABELS A0606_MISS "A0606 SIN INCONSISTENCIAS".
VALUE LABELS A0606_MISS 1'Sí' 2'No' 3'No aplica'.

CTABLES
  /VLABELS VARIABLES=vi16c A0606_MISS DISPLAY=LABEL
  /TABLE vi16c [COUNT F40.0] BY A0606_MISS
  /CATEGORIES VARIABLES=vi16c A0606_MISS ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A0606_T A0606_VI16C_1 A0606_VI16C_2.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.7. Imputación de la variable A0607: Disponen de inodoro de doble descarga? con respecto a la variable VI13.

* Existen 4 casos muestrales registrados incorrectamente como 1 = Sí o 2 = No. Estos valores serán pasados en forma sencilla a la
* categoría 3 = No aplica por simple reasignación.

WEIGHT OFF.
FILTER OFF.
USE ALL.

CTABLES
  /VLABELS VARIABLES=VI13 A0607 DISPLAY=LABEL
  /TABLE VI13 [COUNT F40.0] BY A0607
  /CATEGORIES VARIABLES=VI13 A0607 ORDER=A KEY=VALUE EMPTY=INCLUDE.

RECODE A0607 (ELSE = COPY) INTO A0607_T.
FREQUENCIES A0607_T.

IF (ANY(VI13, 4, 5) & ANY(A0607, 1, 2)) A0607_T = 3.
CTABLES
  /VLABELS VARIABLES=VI13 A0607_T DISPLAY=LABEL
  /TABLE VI13 [COUNT F40.0] BY A0607_T
  /CATEGORIES VARIABLES=VI13 A0607_T ORDER=A KEY=VALUE EMPTY=INCLUDE.

* En esta ocasión, dado que la cantidad de datos es muy pequeña para aplicar el esquema de simulación por variables aleatorias
* binomiales (solo hay 10 datos erróneos), lo que se hará es ordenar en forma ascendente la base de datos ambiental, tomando en 
* este orden las siguientes variables: A01, A0102A, A0102B, A0102C, A02A, A02B, A02C, A02D, A03, A03A, A03B, A04, A04A, 
* A04B, A04B1, A05A, A05B, A05C, A05D, A05E, A0601_MISS, A0602_MISS, A0603_MISS, A0604_MISS, A0605_MISS, A0606_MISS.
* Esto se lo hace con el fin de observar si estos 10 casos caen dentro de alguna conglomeración natural en donde la variable a imputar
* A0607 tenga el mismo valor para cuando la lista de variables anteriores tienen el mismo (o casi el mismo valor).
* Al notar que no existen conglomerados naturales que puedan ayudar a deducir los valores más probables para los 10 casos a
* imputar, se hizo necesario cruzar la información de las variables antes mencionadas con las variables VI13, VI16 y VI16C.
* Se tomó la decisión de conservar el valor 3 = No aplica para los casos en que VI16C = 4 (No recibe agua por tubería sino por otros
* medios). Igualmente, se decidió asignar el valor 1 = Sí para los casos en que VI13 = 1 (Excusado y alcantarillado), VI16 = 1 (Red pública),
* y VI16C = 2 (Por tubería fuera de la vivienda, pero dentro del edificio, lote o terreno). Bajo estas decisiones, se generó la siguiente tabla:
*
* | A0607_MISS |  VI13  |  VI16  |  VI16C |
* =============================.
* |          1         |     1    |    1     |     2     |
* |          2         |     1    |    4     |     2     |
* |          2         |     2    |    1     |     1     |
* |          2         |     2    |    5     |     2     |
* |          2         |     3    |    1     |     2     |
* |          2         |     3    |    4     |     1     |
* |          2         |     3    |    6     |     2     |
* |          3         |     2    |    5     |     4     |
* |          3         |     2    |    6     |     4     |
* |          3         |     3    |    6     |     4     |.

* A continuación, se asignan los valores de la tabla a la nueva variable imputada A0607_MISS.

RECODE A0607_T (ELSE = COPY) INTO A0607_MISS.
FREQUENCIES A0607_MISS A0607_T.
CTABLES
  /VLABELS VARIABLES=VI13 A0607_MISS DISPLAY=LABEL
  /TABLE VI13 [COUNT F40.0] BY A0607_MISS
  /CATEGORIES VARIABLES=VI13 A0607_MISS ORDER=A KEY=VALUE EMPTY=INCLUDE.

DO IF (ANY(VI13, 1, 2, 3) & A0607_T = 3).
COMPUTE A0607_MISS = 2.
IF (VI13 = 1 & VI16 = 1 & VI16C = 2) A0607_MISS = 1.
IF (VI16C = 4) A0607_MISS = 3.
END IF.

FREQUENCIES A0607_MISS.

VARIABLE LABELS A0607_MISS "A0607 SIN INCONSISTENCIAS".
VALUE LABELS A0607_MISS 1'Sí' 2'No' 3'No aplica'.

CTABLES
  /VLABELS VARIABLES=VI13 A0607_MISS DISPLAY=LABEL
  /TABLE VI13 [COUNT F40.0] BY A0607_MISS
  /CATEGORIES VARIABLES=VI13 A0607_MISS ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A0607_T.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.8. Imputación de la variable A0608: Colocan una botella de agua u otro objeto dentro del tanque del inodoro? con respecto a la variable VI13.

* Existen 1 casos muestrales registrados incorrectamente como 1 = Sí o 2 = No. Estos valores serán pasados en forma sencilla a la
* categoría 3 = No aplica por simple reasignación.

WEIGHT OFF.
FILTER OFF.
USE ALL.

CTABLES
  /VLABELS VARIABLES=VI13 A0608 DISPLAY=LABEL
  /TABLE VI13 [COUNT F40.0] BY A0608
  /CATEGORIES VARIABLES=VI13 A0608 ORDER=A KEY=VALUE EMPTY=INCLUDE.

RECODE A0608 (ELSE = COPY) INTO A0608_T.
FREQUENCIES A0608_T.

IF (ANY(VI13, 4, 5) & ANY(A0608, 1, 2)) A0608_T = 3.
CTABLES
  /VLABELS VARIABLES=VI13 A0608_T DISPLAY=LABEL
  /TABLE VI13 [COUNT F40.0] BY A0608_T
  /CATEGORIES VARIABLES=VI13 A0608_T ORDER=A KEY=VALUE EMPTY=INCLUDE.

* En esta ocasión, dado que la cantidad de datos es muy pequeña para aplicar el esquema de simulación por variables aleatorias
* binomiales (solo hay 2 datos erróneos), lo que se hará es ordenar en forma ascendente la base de datos ambiental, tomando en 
* este orden las siguientes variables: A01, A0102A, A0102B, A0102C, A02A, A02B, A02C, A02D, A03, A03A, A03B, A04, A04A, 
* A04B, A04B1, A05A, A05B, A05C, A05D, A05E, A0601_MISS, A0602_MISS, A0603_MISS, A0604_MISS, A0605_MISS, A0606_MISS, A0607_MISS.
* Esto se lo hace con el fin de observar si estos 2 casos caen dentro de alguna conglomeración natural en donde la variable a imputar
* A0608 tenga el mismo valor para cuando la lista de variables anteriores tienen el mismo (o casi el mismo valor).
* Al notar que no existen conglomerados naturales que puedan ayudar a deducir los valores más probables para los 2 casos a
* imputar, se hizo necesario cruzar la información de las variables antes mencionadas con las variables VI13, VI16 y VI16C.
* Se tomó la decisión de conservar el valor 3 = No aplica para los casos en que VI16C = 4 (No recibe agua por tubería sino por otros
* medios). Igualmente, se decidió asignar el valor 1 = Sí para los casos en que VI13 = 1 (Excusado y alcantarillado), VI16 = 1 (Red pública),
* y VI16C = 2 (Por tubería fuera de la vivienda, pero dentro del edificio, lote o terreno). Bajo estas decisiones, se generó la siguiente tabla:
*
* | A0608_MISS |  VI13  |  VI16  |  VI16C |
* =============================.
* |          3         |     3    |    7     |     4     |
* |          3         |     2    |    2     |     3     |.

* Dado que los datos de la variable temporal A0608_T tienen estas características, entonces no se realiza ningún procedimiento adicional,
* quedando los 2 casos de categoría 3 = No aplica como datos correctos.

RECODE A0608_T (ELSE = COPY) INTO A0608_MISS.
FREQUENCIES A0608_MISS A0608_T.
CTABLES
  /VLABELS VARIABLES=VI13 A0608_MISS DISPLAY=LABEL
  /TABLE VI13 [COUNT F40.0] BY A0608_MISS
  /CATEGORIES VARIABLES=VI13 A0608_MISS ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.9. Imputación de la variable A0701: Colocan una botella de agua u otro objeto dentro del tanque del inodoro? con respecto a la variable No_tiene_electrodom.

WEIGHT OFF.
FILTER OFF.
USE ALL.

COMPUTE No_tiene_electrodom = (EQ0201 = 2 & EQ0301 = 2 & EQ0401 = 2 & EQ0501 = 2 & EQ0601 = 2 & EQ0901 = 2 & EQ1001 = 2 & EQ1101 = 2 &
EQ1601 = 2 & EQ1701 = 2 & EQ1801 = 2 & EQ1901 = 2).

CTABLES
  /VLABELS VARIABLES=No_tiene_electrodom A0701 DISPLAY=LABEL
  /TABLE No_tiene_electrodom [COUNT F40.0] BY A0701
  /CATEGORIES VARIABLES=No_tiene_electrodom A0701 ORDER=A KEY=VALUE EMPTY=INCLUDE.

* Existen 16 casos muestrales registrados incorrectamente como 1 = Sí o 2 = No. Estos valores serán pasados en forma sencilla a la
* categoría 3 = No aplica por simple reasignación.

RECODE A0701 (ELSE = COPY) INTO A0701_T.
FREQUENCIES A0701_T.

IF (No_tiene_electrodom = 1 & ANY(A0701, 1, 2)) A0701_T = 3.
FREQUENCIES A0701_T.

CTABLES
  /VLABELS VARIABLES=No_tiene_electrodom A0701_T DISPLAY=LABEL
  /TABLE No_tiene_electrodom [COUNT F40.0] BY A0701_T
  /CATEGORIES VARIABLES=No_tiene_electrodom A0701_T ORDER=A KEY=VALUE EMPTY=INCLUDE.

COMPUTE A0701_NoE_1 = (No_tiene_electrodom = 0 & A0701_T = 3).
FREQUENCIES A0701_NoE_1.

* Existen 214 casos muestrales categorizados erróneamente como 3 = No Aplica. A estos casos se les aplicará el método de imputación
* basado en variables binomiales.

* Una vez hecha la reasignación de los 1 = Sí y 2 = No, se procede a simular los valores erróneos 3 = No Aplica. Por tanto, se necesita
*  aplicar el proceso de imputación por simulación basada en variables binomiales. La probabilidad a priori de asignación desde la categoría
* 3 = No aplica hacia la categoría 1 = Sí es igual a 21864 / (21864 + 6984) = 21864 / 28848 = 0.7579034942, siempre que No_tiene_electrodom = 0.

SET RNG=MT MTINDEX=20. /* Se escoge un valor de MTINDEX que se acerque a 10 veces el valor de p = 0.7579034942, y que minimice su desviación típica.

DO IF (A0701_NoE_1 = 1).
COMPUTE X10 = RV.BINOM(1, 21864 / 28849).
COMPUTE X11 = RV.BINOM(1, 21864 / 28849).
COMPUTE X12 = RV.BINOM(1, 21864 / 28849).
COMPUTE X13 = RV.BINOM(1, 21864 / 28849).
COMPUTE X14 = RV.BINOM(1, 21864 / 28849).
COMPUTE X15 = RV.BINOM(1, 21864 / 28849).
COMPUTE X16 = RV.BINOM(1, 21864 / 28849).
COMPUTE X17 = RV.BINOM(1, 21864 / 28849).
COMPUTE X18 = RV.BINOM(1, 21864 / 28849).
COMPUTE X19 = RV.BINOM(1, 21864 / 28849).
END IF.

COMPUTE XS1 = SUM.1(X10, X11, X12, X13, X14, X15, X16, X17, X18, X19).

DESCRIPTIVES VARIABLES=X10 X11 X12 X13 X14 X15 X16 X17 X18 X19 XS1
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

DELETE VARIABLES X10 X11 X12 X13 X14 X15 X16 X17 X18 X19.

DESCRIPTIVES VARIABLES=XS1
  /STATISTICS=MEAN SUM STDDEV VARIANCE RANGE MIN MAX KURTOSIS SKEWNESS.

RECODE A0701_T (ELSE = COPY) INTO A0701_MISS.
FREQUENCIES A0701_MISS.

DO IF (A0701_NoE_1 = 1).
IF (XS1 < 7.5514) A0701_MISS = 2.
IF (XS1 >= 7.5514)  A0701_MISS = 1.
END IF.

FREQUENCIES A0701_MISS.

VARIABLE LABELS A0701_MISS "A0701 SIN INCONSISTENCIAS".
VALUE LABELS A0701_MISS 1'Sí' 2'No' 3'No aplica'.

CTABLES
  /VLABELS VARIABLES=No_tiene_electrodom A0701_MISS DISPLAY=LABEL
  /TABLE No_tiene_electrodom [COUNT F40.0] BY A0701_MISS
  /CATEGORIES VARIABLES=No_tiene_electrodom A0701_MISS ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A0701_NoE_1.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.10. Imputación de la variable A0704: Planchan la mayor cantidad de ropa posible de una sola vez? con respecto a la variable VI09.
* La variable A0704 no se la validó, puesto que no se dispone de información de equipamiento de plancha.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.11. Imputación de la variable A0706: Disponen de aparatos electrodomésticos (refrigerador, lavadora, secadora) ahorradores de energía? con respecto a la variable VI09.
* La variable A0706 no se la validó, puesto que no se dispone de información de equipamiento acerca de electrodomésticos ahorradores de energía.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* C.12. Imputación de la variable A08: "Durante el mes pasado, al momento de hacer sus compras, en su hogar utilizó con mayor frecuencia:" con respecto a la variable A08D..

WEIGHT OFF.
FILTER OFF.
USE ALL.

FREQUENCIES A08 A08D.

STRING VALOR3 (A3).
COMPUTE VALOR3 = CHAR.SUBSTR(A08D, 1, 3).
FREQUENCIES VALOR3.

DO IF (ANY(VALOR3, "BAL", "BAN", "BIO", "CAN", "CAÑ", "CAñ", "CAR", "CHA", "COS", "LAV", "LON", "MOC", "MOR", "SAC", "SAQ", "USA", "USO", "YUT", "ZAQ")).
COMPUTE OTRO = 1.
ELSE IF (ANY(A08, 1, 2)).
COMPUTE OTRO = $SYSMIS.
END IF.

FREQUENCIES VALOR3 OTRO.

DELETE VARIABLES VALOR3.

* Luego, se asigna manualmente el valor 1 a la variable OTRO cuando el valor "Otro, cual" es ecológico. Cuando atenta contra el ambiente, se asigna el valor 0.
* En caso de duda, se mantienen los missing que ya existen, aunque se recodifican al valor 3. Posteriormente, estos valores se imputarán.

IF (A08D = "LE ENTREGAN EN CARTON") OTRO = 1.
IF (A08D = "EN CARTON") OTRO = 1.
IF (A08D = "CACANASTA") OTRO = 1.
IF (A08D = "BOLSO") OTRO = 1.
IF (A08D = "BOLSAS PLASTICASD NORMALES") OTRO = 0.
IF (A08D = "BOLSAS PLASTICAS COMUNES") OTRO = 0.
IF (A08D = "BOLSA CAñAMO") OTRO = 1.
IF (A08D = "BOLSA BIODEGRADABLE") OTRO = 1.
IF (A08D = "2222125") OTRO = 3.
IF (A08D = "22120") OTRO = 3.
IF (A08D = "217") OTRO = 3.
IF (A08D = "2150") OTRO = 3.
IF (A08D = "215") OTRO = 3.
IF (A08D = "2121") OTRO = 3.
IF (A08D = "2110") OTRO = 3.
IF (A08 = 3 & MISSING(OTRO)) OTRO = 3.
EXECUTE.

COMPUTE PAUTAS = A08.
DO IF (A08 = 3).
IF (OTRO = 0) PAUTAS = 2.
IF (OTRO = 1) PAUTAS = 1.
IF (OTRO = 3) PAUTAS = 3.
END IF.

VARIABLE LABELS PAUTAS "PAUTAS DE CONSUMO RESPONSABLE (TRANSFORMADA)".
VALUE LABELS PAUTAS 2'Nocivo' 1'Ecológico' 3'No sabe'.
FREQUENCIES PAUTAS.

**********************************************************************************************************************************.
* D. Cálculo de los tabulados.

* --- SECCIÓN 12: INFORMACIÓN AMBIENTAL (Jefe de Hogar o Cónyuge)
* --- TABLA 1. HOGARES QUE CLASIFICARON RESIDUOS.

WEIGHT OFF.
FREQUENCIES A01 A0102A A0102B A0102C.
COMPUTE A01_R = MIN(A01, A0102A, A0102B, A0102C).
VARIABLE LABELS A01_R "Hogares que clasificaron sus residuos".
VALUE LABELS A01_R 2'No' 1'Sí'.

WEIGHT BY FEXP.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A01_R DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] 
    + DOMIN [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY A01_R
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A01_R EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 2. HOGARES QUE CLASIFICAN SEGÚN EL TIPO DE RESIDUO.
* --- 2.1 Clasificó residuos orgánicos.

FILTER OFF.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A01 DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] 
    + DOMIN [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY A01
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A01 EMPTY=INCLUDE.

* --- 2.2 Clasificó residuos inorgánicos: Papel, cartón.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A0102A DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] 
    + DOMIN [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY A0102A
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A0102A EMPTY=INCLUDE.

* --- 2.3 Clasificó residuos inorgánicos: Plástico.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A0102B DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] 
    + DOMIN [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY A0102B
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A0102B EMPTY=INCLUDE.

* --- 2.4 Clasificó residuos inorgánicos: Vidrio.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A0102C DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] 
    + DOMIN [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY A0102C
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A0102C EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 3. HOGARES QUE CLASIFICARON LOS RESIDUOS POR CIUDADES AUTORREPRESENTADAS.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A01_R DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
    + DOMIN [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY A01_R
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A01_R EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 4. PRINCIPALMENTE, CÓMO ELIMINÓ LOS RESIDUOS DE ORGÁNICOS.

SPLIT FILE OFF.
FILTER OFF.
USE ALL.
EXECUTE.
SORT CASES BY A01_R.
SPLIT FILE SEPARATE BY A01_R.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A02A DISPLAY=LABEL
  /TABLE NACIONAL + AREA + DOMIN BY A02A [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A02A ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 5. PRINCIPALMENTE, EN SU HOGAR DURANTE LOS ÚLTIMOS 12 MESES, CÓMO ELIMINÓ LOS RESIDUOS DE PLÁSTICO.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A02B DISPLAY=LABEL
  /TABLE NACIONAL + AREA + DOMIN BY A02B [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A02B ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 6. PRINCIPALMENTE, EN SU HOGAR DURANTE LOS ÚLTIMOS 12 MESES, CÓMO ELIMINÓ LOS RESIDUOS DE VIDRIO.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A02C DISPLAY=LABEL
  /TABLE NACIONAL + AREA + DOMIN BY A02C [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A02C ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 7. PRINCIPALMENTE, EN SU HOGAR DURANTE LOS ÚLTIMOS 12 MESES,CÓMO ELIMINÓ LOS RESIDUOS DE PAPEL, CARTÓN.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A02D DISPLAY=LABEL
  /TABLE NACIONAL + AREA + DOMIN BY A02D [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A02D ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

SPLIT FILE OFF.
DELETE VARIABLES A01_R.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 8.  HOGARES QUE UTILIZARON PILAS.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A03 DISPLAY=LABEL
  /TABLE NACIONAL + AREA + DOMIN BY A03 [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=A03 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 9.  HOGARES QUE UTILIZARON PILAS, DE LAS CUALES AL MENOS UNA ES RECARGABLE.

COMPUTE usa_pilas_rec = (A03B > 0).
VARIABLE LABELS usa_pilas_rec "Hogares que utilizaron pilas recargables".
VALUE LABELS usa_pilas_rec 0'No' 1'Sí'.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN usa_pilas_rec DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.COUNT PCT40.2]  + AREA [COUNT F40.0, ROWPCT.COUNT PCT40.2] 
    + DOMIN [COUNT F40.0, ROWPCT.COUNT PCT40.2] BY usa_pilas_rec
  /CATEGORIES VARIABLES= AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=NO POSITION=AFTER
  /CATEGORIES VARIABLES=usa_pilas_rec ORDER=D KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER.

DELETE VARIABLES usa_pilas_rec.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 10.  DISPOSICIÓN FINAL DE LAS PILAS.

COMPUTE A05A_temp = A05A.
RECODE A05A_temp (5, 6=SYSMIS).
VARIABLE LABELS A05A_temp "Disposición final de las pilas".
VALUE LABELS A05A_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Guardó, vendió, regaló'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó a la quebrada, desagüe'.

CTABLES
  /VLABELS VARIABLES=NACIONAL A05A_temp DISPLAY=LABEL
  /TABLE A05A_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=A05A_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A05A_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 11.  CANTIDAD DE PILAS UTILIZADAS POR LOS HOGARES SEGÚN TIPO.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A03A A03B DISPLAY=LABEL
  /TABLE NACIONAL [C] + AREA [C] + DOMIN [C] BY A03A [S][SUM] + A03B [S][SUM]
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 12.  HOGARES QUE UTILIZAN FOCOS.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A04 DISPLAY=LABEL
  /TABLE NACIONAL + AREA + DOMIN BY A04 [C][COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=A04 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 13.  HOGARES QUE UTILIZAN FOCOS AHORRADORES.

FILTER OFF.
USE ALL.

COMPUTE usa_focos_aho = (A04B > 0).
VARIABLE LABELS usa_focos_aho "Hogares que utilizan focos ahorradores".
VALUE LABELS usa_focos_aho 0'No' 1'Sí'.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN usa_focos_aho DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] 
      + DOMIN [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY usa_focos_aho
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=usa_focos_aho ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 14.  DISPOSICIÓN FINAL UTILIZADA POR LOS HOGARES PARA LOS FOCOS AHORRADORES.

FILTER OFF.
USE ALL.

COMPUTE filtro_electricidad = (VI09 <= 2).

COMPUTE A05E_temp = A05E.
RECODE A05E_temp (5, 6=SYSMIS).
VARIABLE LABELS A05E_temp "Disposición final de los focos ahorradores".
VALUE LABELS A05E_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Guardó, vendió, regaló'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó a la quebrada, desagüe'.

COMPUTE filtro_compuesto = usa_focos_aho & filtro_electricidad.

FILTER BY filtro_compuesto.
CTABLES
  /VLABELS VARIABLES=NACIONAL A05E_temp DISPLAY=LABEL
  /TABLE A05E_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=A05E_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

FILTER OFF.
USE ALL.

DELETE VARIABLES A05E_temp usa_focos_aho filtro_compuesto.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 15.  NÚMERO DE FOCOS Y FOCOS AHORRADORES, FOCOS AHORRADORES LED Y FOCOS NO AHORRADORES.

FILTER OFF.
USE ALL.

FILTER BY filtro_electricidad.
CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN A04A A04B A04B1 DISPLAY=LABEL
  /TABLE NACIONAL [C] + AREA [C] + DOMIN [C] BY A04A [S][SUM] + A04B [S][SUM] + A04B1 [S][SUM]
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE.

FILTER OFF.
USE ALL.

DELETE VARIABLES filtro_electricidad.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 16.  DISPOSICIÓN FINAL DE LOS DESECHOS FARMACÉUTICOS (MEDICAMENTOS).

COMPUTE A05B_temp = A05B.
RECODE A05B_temp (5, 6=SYSMIS).
VARIABLE LABELS A05B_temp "Disposición final de los desechos farmaceúticos (medicamentos)".
VALUE LABELS A05B_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Guardó, vendió, regaló'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó a la quebrada, desagüe'.

CTABLES
  /VLABELS VARIABLES=NACIONAL A05B_temp DISPLAY=LABEL
  /TABLE A05B_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=A05B_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A05B_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 17.  DISPOSICIÓN FINAL DE ACEITE Y/O GRASAS (COCINA).

COMPUTE A05D_temp = A05D.
RECODE A05D_temp (2, 5 = 2) (6=SYSMIS) (ELSE = COPY).
VARIABLE LABELS A05D_temp "Disposición final de aceite y/o grasas (cocina)".
VALUE LABELS A05D_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Guardó, vendió, regaló'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó a la quebrada, desagüe'.

CTABLES
  /VLABELS VARIABLES=NACIONAL A05D_temp DISPLAY=LABEL
  /TABLE A05D_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=A05D_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A05D_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 18.  DISPOSICIÓN FINAL DE DESECHOS ELECTRÓNICOS / ELÉCTRICOS.

COMPUTE A05C_temp = A05C.
RECODE A05C_temp (5, 6=SYSMIS).
VARIABLE LABELS A05C_temp "Disposición final de desechos electrónicos / eléctricos".
VALUE LABELS A05C_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Guardó, vendió, regaló'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó a la quebrada, desagüe'.

CTABLES
  /VLABELS VARIABLES=NACIONAL A05C_temp DISPLAY=LABEL
  /TABLE A05C_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=A05C_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES A05C_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 19.  PRÁCTICAS DE AHORRO DE AGUA REALIZADAS POR LOS HOGARES.

FILTER OFF.
USE ALL.

COMPUTE FILTRO_PAHA = (VI16 = 1 & VI16C = 1).

FILTER BY FILTRO_PAHA.

CTABLES
  /VLABELS VARIABLES=A0601_MISS A0602_MISS A0603_MISS A0604_MISS A0605_MISS A0606_MISS DISPLAY=LABEL
  /TABLE A0601_MISS [C][COUNT F40.0, COLPCT.VALIDN PCT40.1] + A0602_MISS [C][COUNT F40.0, COLPCT.VALIDN PCT40.1] +
               A0603_MISS [C][COUNT F40.0, COLPCT.VALIDN PCT40.1] + A0604_MISS [C][COUNT F40.0, COLPCT.VALIDN PCT40.1] +
               A0605_MISS [C][COUNT F40.0, COLPCT.VALIDN PCT40.1] + A0606_MISS [C][COUNT F40.0, COLPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=A0601_MISS [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=A0602_MISS [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=A0603_MISS [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=A0604_MISS [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=A0605_MISS [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=A0606_MISS [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

FILTER OFF.
USE ALL.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 20.  HOGARES QUE TIENEN DISPOSITIVOS DE AHORRO DE AGUA.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE A07_A08 = MIN (A0607_MISS, A0608_MISS).
VARIABLE LABELS A07_A08 "Disponen de inodoro doble descarga / botella de agua dentro del tanque del inodoro".
VALUE LABELS A07_A08 1'Sí' 2'No' 3'No aplica'.
FREQUENCIES A07_A08.

FILTER BY FILTRO_PAHA.

WEIGHT BY FEXP.
CTABLES
  /VLABELS VARIABLES=A07_A08 DISPLAY=LABEL
  /TABLE A07_A08 [C][COUNT F40.0, COLPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=A07_A08 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

FILTER OFF.
USE ALL.

DELETE VARIABLES FILTRO_PAHA A07_A08.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 21.  PRÁCTICAS DE AHORRO DE ENERGÍA REALIZADAS POR LOS HOGARES.

FILTER OFF.
USE ALL.

COMPUTE FILTRO_ENERGIA = (VI09 = 1).

COMPUTE FILTRO_A0701 = (EQ0101 = 1 | EQ0201 = 1 | EQ0301 = 1 | EQ0401 = 1 | EQ0501 = 1 | EQ0601 = 1 |
EQ0901 = 1 | EQ1001 = 1 | EQ1101 = 1 | EQ1601 = 1 | EQ1801 = 1) & FILTRO_ENERGIA.

FILTER BY FILTRO_A0701.

CTABLES
  /VLABELS VARIABLES=A0701_MISS DISPLAY=LABEL
  /TABLE A0701_MISS [C][COUNT F40.0, COLPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=A0701_MISS [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

DELETE VARIABLES FILTRO_A0701.

*-----------------------------------------------------------------------------------------------------------------------------------------------------.

FILTER OFF.
USE ALL.

COMPUTE FILTRO_A0702 = (A04 = 1) & FILTRO_ENERGIA.

FILTER BY FILTRO_A0702.

CTABLES
  /VLABELS VARIABLES=A0702 DISPLAY=LABEL
  /TABLE A0702 [C][COUNT F40.0, COLPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=A0702 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

DELETE VARIABLES FILTRO_A0702.

*-----------------------------------------------------------------------------------------------------------------------------------------------------.

FILTER OFF.
USE ALL.

COMPUTE FILTRO_A0703 = (EQ0101 = 1) & FILTRO_ENERGIA.

FILTER BY FILTRO_A0703.

CTABLES
  /VLABELS VARIABLES=A0703 DISPLAY=LABEL
  /TABLE A0703 [C][COUNT F40.0, COLPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=A0703 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

DELETE VARIABLES FILTRO_A0703.

*-----------------------------------------------------------------------------------------------------------------------------------------------------.

FILTER OFF.
USE ALL.

COMPUTE FILTRO_A0704 = FILTRO_ENERGIA.

FILTER BY FILTRO_A0704.

CTABLES
  /VLABELS VARIABLES=A0704 DISPLAY=LABEL
  /TABLE A0704 [C][COUNT F40.0, COLPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=A0704 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

DELETE VARIABLES FILTRO_A0704.

*-----------------------------------------------------------------------------------------------------------------------------------------------------.

FILTER OFF.
USE ALL.

COMPUTE FILTRO_A0705 = FILTRO_ENERGIA.

FILTER BY FILTRO_A0705.

CTABLES
  /VLABELS VARIABLES=A0705 DISPLAY=LABEL
  /TABLE A0705 [C][COUNT F40.0, COLPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=A0705 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

FILTER OFF.
USE ALL.

DELETE VARIABLES FILTRO_A0705.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 22.  HOGARES QUE TIENEN DISPOSITIVOS AHORRADORES DE ENERGÍA.

FILTER BY FILTRO_ENERGIA.

CTABLES
  /VLABELS VARIABLES=A0706 A0707 DISPLAY=LABEL
  /TABLE A0706 [C][COUNT F40.0, COLPCT.VALIDN PCT40.1] + A0707 [C][COUNT F40.0, COLPCT.VALIDN 
    PCT40.1]
  /CATEGORIES VARIABLES=A0706 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=A0707 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

FILTER OFF.
USE ALL.

DELETE VARIABLES FILTRO_ENERGIA.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 23.  TIPOS DE BOLSAS UTILIZADAS POR LOS HOGARES PARA REALIZAR SUS COMPRAS.

CTABLES
  /VLABELS VARIABLES=PAUTAS DISPLAY=LABEL
  /TABLE PAUTAS [COUNT F40.0, COLPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=PAUTAS ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 24.  TIPOS DE BOLSAS UTILIZADAS POR LOS HOGARES PARA REALIZAR SUS COMPRAS POR REGIÓN.

CTABLES
  /VLABELS VARIABLES=REG_NATURAL PAUTAS DISPLAY=LABEL
  /TABLE REG_NATURAL BY PAUTAS [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=REG_NATURAL PAUTAS ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 14: DATOS DE LA VIVIENDA Y EL HOGAR (Jefe o Cónyuge)
* --- TABLA 26.  HOGARES QUE DISPONEN DE BICICLETAS.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN EQ1201 DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [C][COUNT F40.0, ROWPCT.VALIDN 
    PCT40.1] + DOMIN [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY EQ1201
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=EQ1201 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 5.1: INFORMACIÓN AMBIENTAL (Personas de 5 años y más)
* --- TABLA 27.  HOGARES EN LOS QUE AL MENOS UNA PERSONA UTILIZÓ BICICLETA.

GET
  FILE='C:\ENEMDU\Datos\Bases\201712_EnemduBDD_15anios.sav'.

SORT CASES BY AREA (A) CIUDAD (A) CONGLOMERADO (A) ZONA (A) SECTOR (A) PANELM (A) VIVIENDA (A) HOGAR (A) P01 (A).

DATASET NAME Personas WINDOW=FRONT.

COMPUTE FILTRO_5 = (P03 >= 5).
FILTER OFF.
USE ALL.
FILTER BY FILTRO_5.

DATASET ACTIVATE Personas.
AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /PRESORTED
  /BREAK=AREA CIUDAD CONGLOMERADO ZONA SECTOR PANELM VIVIENDA HOGAR
  /PIA01A_min 'Hogares donde al menos un miembro usa bicicleta'=MIN(PIA01A).

FREQUENCIES PIA01A_min.
FILTER OFF.
USE ALL.

SAVE OUTFILE='C:\ENEMDU\Datos\Bases\201712_EnemduBDD_15anios.sav'
 /COMPRESSED.

DATASET ACTIVATE Ambientales WINDOW=FRONT.
SORT CASES BY AREA (A) CIUDAD (A) CONGLOMERADO (A) ZONA (A) SECTOR (A) PANELM (A) VIVIENDA (A) HOGAR (A).
COMPUTE registro_original = 1.
FREQUENCIES registro_original.

DATASET ACTIVATE Ambientales.
MATCH FILES /TABLE=*
  /FILE='Personas'
  /RENAME (p01 p10a p10b p11 p12a p12b p13 p14 p15 p15aa p15ab p16a p16b p17a p17b p18 p19a p19b 
    p02 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p03 p30 p31 p32 p33 p34 p35 p36 p37 p38 p39 p04 sd01 
    sd021 sd0210 sd0211 sd022 sd023 sd024 sd025 sd026 sd027 sd028 sd029 sd03 p40 p41 p42 p42a p43 p44a 
    p44b p44c p44d p44e p44f p44g p44h p44i p44j p44k p45 p46 p47a p47b p48 p49 p50 p51a p51b p51c p52 
    p53 p54 p54a p55 p56a p56b p57 p58 p59 p05a p05b p06 p60a p60b p60c p60d p60e p60f p60g p60h p60i 
    p60j p60k p61a101 p61a102 p61a103 p61a11 p61a111 p61a112 p61a113 p61a12 p61a13 p61a2 p61a31 p61a32 
    p61a33 p61a34 p61a4 p61a5 p61a61 p61a62 p61a7 p61a8 p61a91 p61a92 p61b1 p63 p64a p64b p65 p66 p67 
    p68a p68b p69 p07 p70a p70b p71a p71b p72a p72b p73a p73b p74a p74b p75 p76 p77 p78 p79 p79a1 p79a2 
    p79b1 p79b2 p08 p09 ced01a ciud5 CONDACTN cod_inf desem desemab desem1 desem2 desemoc empleo adec 
    nc nr epobreza fexp FILTRO_5 grupo1 id_sector ingrl ingpc oinad pe01 pe02a pe02b pe03 pe03a1 pe03a2 
    pe03a3 pe03a4 pe03a5 pe04 pe05a pe05b pe06 pe07 pe08 pe09a pe09b pia01a pia01b pia02 pia03 
    plan_muestreo empdom formal informal nocla pean pein petn t_a pobreza ps01 ps02a ps02b ps02c ps03 
    ps03a ps04a ps04b ps04c ps05 ps05a ps05b ps06 ps06a ps06b ps07 ps07a ps07aa ps07ab ps07b ps08 ps08a 
    ps08b ps09 ps09a ps09b ps10 ps10a ps10b ps11 ps11a ps12 ps12a pt01a pt01b pt02 pt03 pt04a pt04b 
    pt04c pt05 pt06a pt06b pt06c pt06d pt07 pt08 pt1a pt1b1 pt1b2 pt1b3 pt1b4 pt1b5 pt1b6 rama1 SECEMP 
    seg011 seg0110 seg012 seg013 seg014 seg015 seg016 seg017 seg018 seg019 seg02 seg03 seg041 seg042 
    seg043 seg044 seg045 seg046 seg047 seg048 seg05 seg06 seg07 seg08 seg091 seg092 seg093 seg101 
    seg102 seg103 seg104 seg111 seg112 seg113 seg121 seg122 seg123 sub sub_w sub_h = d0 d1 d2 d3 d4 d5 
    d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 
    d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 d50 d51 d52 d53 d54 d55 d56 
    d57 d58 d59 d60 d61 d62 d63 d64 d65 d66 d67 d68 d69 d70 d71 d72 d73 d74 d75 d76 d77 d78 d79 d80 d81 
    d82 d83 d84 d85 d86 d87 d88 d89 d90 d91 d92 d93 d94 d95 d96 d97 d98 d99 d100 d101 d102 d103 d104 
    d105 d106 d107 d108 d109 d110 d111 d112 d113 d114 d115 d116 d117 d118 d119 d120 d121 d122 d123 d124 
    d125 d126 d127 d128 d129 d130 d131 d132 d133 d134 d135 d136 d137 d138 d139 d140 d141 d142 d143 d144 
    d145 d146 d147 d148 d149 d150 d151 d152 d153 d154 d155 d156 d157 d158 d159 d160 d161 d162 d163 d164 
    d165 d166 d167 d168 d169 d170 d171 d172 d173 d174 d175 d176 d177 d178 d179 d180 d181 d182 d183 d184 
    d185 d186 d187 d188 d189 d190 d191 d192 d193 d194 d195 d196 d197 d198 d199 d200 d201 d202 d203 d204 
    d205 d206 d207 d208 d209 d210 d211 d212 d213 d214 d215 d216 d217 d218 d219 d220 d221 d222 d223 d224 
    d225 d226 d227 d228 d229 d230 d231 d232 d233 d234 d235 d236 d237 d238 d239 d240 d241 d242 d243 d244 
    d245 d246 d247 d248 d249 d250 d251 d252 d253 d254 d255 d256 d257 d258 d259 d260 d261 d262 d263 d264 
    d265 d266 d267 d268 d269 d270 d271 d272 d273 d274 d275 d276 d277 d278 d279 d280 d281 d282 d283 d284 
    d285 d286 d287 d288 d289 d290 d291 d292 d293 d294 d295 d296 d297 d298 d299 d300 d301 d302 d303 d304 
    d305) 
  /BY area ciudad conglomerado zona sector panelm vivienda hogar
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 
    d50 d51 d52 d53 d54 d55 d56 d57 d58 d59 d60 d61 d62 d63 d64 d65 d66 d67 d68 d69 d70 d71 d72 d73 d74 
    d75 d76 d77 d78 d79 d80 d81 d82 d83 d84 d85 d86 d87 d88 d89 d90 d91 d92 d93 d94 d95 d96 d97 d98 d99 
    d100 d101 d102 d103 d104 d105 d106 d107 d108 d109 d110 d111 d112 d113 d114 d115 d116 d117 d118 d119 
    d120 d121 d122 d123 d124 d125 d126 d127 d128 d129 d130 d131 d132 d133 d134 d135 d136 d137 d138 d139 
    d140 d141 d142 d143 d144 d145 d146 d147 d148 d149 d150 d151 d152 d153 d154 d155 d156 d157 d158 d159 
    d160 d161 d162 d163 d164 d165 d166 d167 d168 d169 d170 d171 d172 d173 d174 d175 d176 d177 d178 d179 
    d180 d181 d182 d183 d184 d185 d186 d187 d188 d189 d190 d191 d192 d193 d194 d195 d196 d197 d198 d199 
    d200 d201 d202 d203 d204 d205 d206 d207 d208 d209 d210 d211 d212 d213 d214 d215 d216 d217 d218 d219 
    d220 d221 d222 d223 d224 d225 d226 d227 d228 d229 d230 d231 d232 d233 d234 d235 d236 d237 d238 d239 
    d240 d241 d242 d243 d244 d245 d246 d247 d248 d249 d250 d251 d252 d253 d254 d255 d256 d257 d258 d259 
    d260 d261 d262 d263 d264 d265 d266 d267 d268 d269 d270 d271 d272 d273 d274 d275 d276 d277 d278 d279 
    d280 d281 d282 d283 d284 d285 d286 d287 d288 d289 d290 d291 d292 d293 d294 d295 d296 d297 d298 d299 
    d300 d301 d302 d303 d304 d305.
EXECUTE.

* Identificar casos duplicados.
SORT CASES BY AREA(A) CIUDAD(A) CONGLOMERADO(A) ZONA(A) SECTOR(A) PANELM(A) VIVIENDA(A) HOGAR(A).
MATCH FILES
  /FILE=*
  /BY AREA CIUDAD CONGLOMERADO ZONA SECTOR PANELM VIVIENDA HOGAR
  /FIRST=HogarUnico.
VARIABLE LABELS  HogarUnico 'Indicador de cada primer caso de coincidencia como primario'.
VALUE LABELS  HogarUnico 0 'Caso duplicado' 1 'Caso primario'.
VARIABLE LEVEL  HogarUnico (ORDINAL).
FREQUENCIES VARIABLES=HogarUnico.
EXECUTE.

FILTER OFF.
USE ALL.
SELECT IF  (NOT(HogarUnico=0)).
EXECUTE.

DELETE VARIABLES HogarUnico.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN PIA01A_min DISPLAY=LABEL
  /TABLE NACIONAL + AREA + DOMIN BY PIA01A_min [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=PIA01A_min ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 5.1: INFORMACIÓN AMBIENTAL (Personas de 5 años y más)
* --- TABLA 28.  USO DE BICICLETA POR PERSONA.

DATASET ACTIVATE Personas WINDOW=FRONT.

RECODE p03 (5 THRU 14 = 1) (15 THRU 24 = 2) (25 THRU 34 = 3) (35 THRU 44 = 4) (45 THRU 64 = 5)
(65 THRU HI = 6) INTO Grupo_Edad_BICI.
VARIABLE LABELS Grupo_Edad_BICI "Grupos de edad para uso de bicicleta por personas".
VALUE LABELS Grupo_Edad_BICI 1'Grupo 5-14 años'
2'Grupo 15-24 años'
3'Grupo 25-34 años'
4'Grupo 35-44 años'
5'Grupo 45-64 años'
6'Grupo 65 años o más'.

COMPUTE NACIONAL=1.
VARIABLE LABELS NACIONAL "NACIONAL".
VALUE LABELS NACIONAL 1"Nacional".

WEIGHT BY FEXP.

DATASET ACTIVATE Personas.

CTABLES
  /VLABELS VARIABLES=NACIONAL Grupo_Edad_BICI PIA01A DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + Grupo_Edad_BICI [C][COUNT F40.0, 
    ROWPCT.VALIDN PCT40.1] BY PIA01A [C]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Grupo_Edad_BICI ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=PIA01A ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 5.1: INFORMACIÓN AMBIENTAL (Personas de 5 años y más)
* --- TABLA 29.  POBLACIÓN QUE UTILIZÓ BICICLETAS POR GRUPO DE EDAD.

* Tablas personalizadas.
CTABLES
  /VLABELS VARIABLES=NACIONAL Grupo_Edad_BICI PIA01A DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, COLPCT.COUNT PCT40.1] + Grupo_Edad_BICI [C][COUNT F40.0, COLPCT.COUNT PCT40.1] BY PIA01A [C]
  /CATEGORIES VARIABLES=NACIONAL Grupo_Edad_BICI ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=PIA01A [1] EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 5.1: INFORMACIÓN AMBIENTAL (Personas de 5 años y más)
* --- TABLA 30.  FRECUENCIA DEL USO DE BICICLETAS.

DATASET ACTIVATE Personas WINDOW=FRONT.

IF (CIUDAD=170150) DOMIN=1.
IF (CIUDAD=90150) DOMIN=2.
IF (CIUDAD=10150) DOMIN=3.
IF (CIUDAD=180150) DOMIN=4.
IF (CIUDAD=70150) DOMIN=5.

VARIABLE LABELS DOMIN 'Ciudades de Dominio'.
VALUE LABELS DOMIN 1 'Quito' 2 'Guayaquil' 3 'Cuenca' 4 'Ambato' 5 'Machala'.
EXECUTE.

FILTER BY FILTRO_5.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN PIA01B DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [C][COUNT F40.0, ROWPCT.VALIDN 
    PCT40.1] + DOMIN [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY PIA01B [C]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=PIA01B ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

FILTER OFF.
USE ALL.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 5.1: INFORMACIÓN AMBIENTAL (Personas de 5 años y más)
* --- TABLA 31.  MEDIO DE TRASLADO DE LAS PERSONAS DE 5 AÑOS Y MÁS A NIVEL NACIONAL.

DATASET ACTIVATE Personas WINDOW=FRONT.

RECODE PIA02 (1,2 = 1) (3 = 2) (4 = 3) (5 = 4) (6 = 5) INTO MEDIO_TRASLADO.
VARIABLE LABELS MEDIO_TRASLADO "Medio de traslado de las personas de 5 años y más".
VALUE LABELS MEDIO_TRASLADO 1'Vehículo particular'
2'Transporte público'
3'Bicicleta'
4'Caminar'
5'Otro, cuál'.

FILTER OFF.
USE ALL.
FILTER BY FILTRO_5.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN MEDIO_TRASLADO DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [C][COUNT F40.0, ROWPCT.VALIDN 
    PCT40.1] + DOMIN [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY MEDIO_TRASLADO [C]
  /CATEGORIES VARIABLES=NACIONAL MEDIO_TRASLADO ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE.

FILTER OFF.
USE ALL.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 5.1: INFORMACIÓN AMBIENTAL (Personas de 5 años y más)
* --- TABLA 32.  USO DEL VEHÍCULO PARTICULAR (según dominio y área).

DATASET ACTIVATE Personas WINDOW=FRONT.

FILTER OFF.
USE ALL.
FILTER BY FILTRO_5.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA DOMIN PIA02 DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [C][COUNT F40.0, ROWPCT.VALIDN 
    PCT40.1] + DOMIN [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY PIA02
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=AREA DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=PIA02 [1, 2] EMPTY=INCLUDE.

FILTER OFF.
USE ALL.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 5.1: INFORMACIÓN AMBIENTAL (Personas de 5 años y más)
* --- TABLA 33.  MOVILIDAD DE LA POBLACIÓN POR GRUPO DE EDAD.

DATASET ACTIVATE Personas WINDOW=FRONT.

FILTER OFF.
USE ALL.
FILTER BY FILTRO_5.

CTABLES
  /VLABELS VARIABLES=NACIONAL Grupo_Edad_BICI MEDIO_TRASLADO DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + Grupo_Edad_BICI [C][COUNT F40.0, 
    ROWPCT.VALIDN  PCT40.1] BY MEDIO_TRASLADO
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Grupo_Edad_BICI ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=MEDIO_TRASLADO EMPTY=INCLUDE.

FILTER OFF.
USE ALL.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o cónyuge)
* --- TABLA 34.  COMBUSTIBLE MÁS UTILIZADO POR PARTE DE LOS HOGARES.

SAVE OUTFILE='C:\ENEMDU\Datos\Bases\PERSONAS.sav'
 /COMPRESSED.

DATASET ACTIVATE Ambientales WINDOW=FRONT.
DATASET CLOSE Personas.

COMPUTE FILTRO_POSEE_VEH = (EQ1301 = 1 | EQ1401 = 1).

FILTER OFF.
USE ALL.

FILTER BY FILTRO_POSEE_VEH.
CTABLES
  /VLABELS VARIABLES=A0901 A0902 A0903 A0905 DOMIN DISPLAY=LABEL
  /TABLE A0901 [C][COUNT F40.0, COLPCT.VALIDN PCT40.1] + A0902 [C][COUNT F40.0, COLPCT.VALIDN 
    PCT40.1] + A0903 [C][COUNT F40.0, COLPCT.VALIDN PCT40.1] + A0905 [C][COUNT F40.0, COLPCT.VALIDN 
    PCT40.1] BY DOMIN [C]
  /CATEGORIES VARIABLES=A0901 A0902 A0903 A0905 ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=DOMIN ORDER=A KEY=VALUE EMPTY=INCLUDE.

FILTER OFF.
USE ALL.

DELETE VARIABLES FILTRO_POSEE_VEH.

SAVE OUTFILE='C:\ENEMDU\Datos\Bases\AMBIENTE.sav'
 /COMPRESSED.

*************************************************************************************************************
* FIN DE LA SINTAXIS DE TABULADOS MÓDULO AMBIENTAL - ENEMDU 2017.
*************************************************************************************************************.

